pub trait UpdateProvider:
Send
+ Sync
+ 'static {
// Required method
fn check_update<'a>(
&'a self,
target: UpdateTarget,
) -> BoxFuture<'a, Result<Option<UpdatePackageInfo>, ProviderError>>;
}Expand description
Update contract shared by app and lxapp update implementations.
Required Methods
Sourcefn check_update<'a>(
&'a self,
target: UpdateTarget,
) -> BoxFuture<'a, Result<Option<UpdatePackageInfo>, ProviderError>>
fn check_update<'a>( &'a self, target: UpdateTarget, ) -> BoxFuture<'a, Result<Option<UpdatePackageInfo>, ProviderError>>
Returns Some(package) when an update package exists and None when the target
is already up to date or no matching package is available.